	SUBROUTINE BCOPY (BIN,BOUT,ILEN)
C COPY BYTE STRING FROM BIN TO BOUT
C
C	BIN		INPUT CHARACTER STRING
C	BOUT		OUTPUT CHARACTER STRING
C	ILEN		NUMBER OF CHARACTERS IN BIN COPIED TO BOUT
C
	IMPLICIT BYTE (B), LOGICAL*1 (L), INTEGER*2 (I-K,M,N)
	DIMENSION BOUT(1),BIN(1)
	IF (ILEN .EQ. 0) RETURN
	DO 100 I=1,ILEN
100	BOUT(I) = BIN(I)
	RETURN
	END
